@@ -48,10 +48,11 @@ class Collate:
         if the enhanced subclass is in either NONRTM or MACROLIDES then then use the groups specified by Norelle. If it is empty (-) then fall back on the AMRFinder subclass, else report the extended subclass
         """
         gene_id_col = "Gene symbol" if colname != "refseq_protein_accession" else "Accession of closest sequence" # to get the name of drug and the drugclass
+        
         if reftab[reftab[colname] == row[1][gene_id_col]].empty:
             d = 'Unknown'
             for i in ['genbank_protein_accession','refseq_nucleotide_accession','genbank_nucleotide_accession']:
-                
+                # print(reftab[reftab[i] == row[1][gene_id_col]])
                 if not reftab[reftab[i] == row[1][gene_id_col]].empty:
                     d= reftab[reftab[i] == row[1][gene_id_col]]['enhanced_subclass'].values[0]
                     break
@@ -329,6 +330,7 @@ class MduCollate(Collate):
         self.logger.addHandler(ch) 
         self.logger.addHandler(fh)
         self.sop = args.sop
+        self.sop_name = args.sop_name
         self.mduqc = args.qc
         self.db = args.db
         self.partials = args.partials
@@ -339,9 +341,10 @@ class MduCollate(Collate):
             "Shigella":"CPase_ESBL_AmpC_16S_NEG",
             "Staphylococcus":"Mec_VanAB_Linez_NEG",
             "Enterococcus":"Van_Linez_NEG",
-            "Other":"Cpase_16S_mcr_NEG"
+            "Other":"CPase_16S_mcr_NEG"
         }
         self.REPORTING = {"Salmonella enterica":self.mdu_reporting_salmonella}
+
     def mdu_qc_tab(self):
         self.logger.info(f"Checking the format of the QC file")
         cols = ["ISOLATE", 'SPECIES_EXP', 'SPECIES_OBS', 'TEST_QC']
@@ -354,7 +357,7 @@ class MduCollate(Collate):
 
         pos = pandas.DataFrame(data = {"ISOLATE": "9999-99888", "TEST_QC" : "PASS", "SPECIES_EXP":"Staphylococcus aureus", "SPECIES_OBS":"Staphylococcus aureus" }, index = [0])
         
-        return tab.append(pos)
+        return pandas.concat([tab,pos])
 
     def strip_bla(self, gene):
         '''
@@ -394,7 +397,7 @@ class MduCollate(Collate):
         if genus in self.NONE_CODES:
             return self.NONE_CODES[genus]
         else:
-            return "GENRL_AMR_NEG1"
+            return "CPase_16S_mcr_NEG"
 
     def assign_itemcode(self,mduid, reg):
         self.logger.info(f"Checking for item code")
@@ -416,7 +419,7 @@ class MduCollate(Collate):
 
     def _ampicillin_res_sal(self, col, gene):
         
-        if col in [ 'Beta-lactamase (not ESBL or carbapenemase)','ESBL','ESBL (AmpC type)', 'Beta-lactamase (narrow-spectrum)','Beta-lactamase (unknown spectrum)'] or 'Ampicillin' in col:
+        if col in [ 'Beta-lactam','ESBL','AmpC'] or 'Ampicillin' in col:
             return gene
         return ''
 
@@ -434,7 +437,7 @@ class MduCollate(Collate):
 
     def _cefo_ampc_res_sal(self, col, gene):
 
-        if col == 'ESBL (AmpC type)':
+        if 'AmpC' in col :
             return gene
         return ''
     
@@ -451,7 +454,7 @@ class MduCollate(Collate):
         return ''
 
     def _gentamicin_res_salm(self, col, gene):
-        if col in ['Gentamicin', 'Aminoglycosides (Ribosomal methyltransferase)']: #change
+        if col in ['Gentamicin', 'Aminoglycosides (Ribosomal methyltransferase)']: 
             return gene
         return ''
     
@@ -522,7 +525,7 @@ class MduCollate(Collate):
         # Ciprofloxacin - ResMech	Ciprofloxacin - Interpretation	
         # Azithromycin - ResMech	Azithromycin - Interpretation
 
-        mduidreg = re.compile(r'(?P<id>[0-9]{4}-[0-9]{5,6})-?(?P<itemcode>.{1,2})?')
+        mduidreg = re.compile(r'(?P<id>[0-9]{4}-[0-9]{5,6})-?(?P<itemcode>.{1,})?')
         
         all_genes = self.get_all_genes(row)
         all_genes = [a for a in all_genes if a != row[1]['Isolate'] and a != '']
@@ -601,8 +604,8 @@ class MduCollate(Collate):
             elif res == 'Ciprofloxacin':
                 if tmp_results[res] == []:
                     results[f"{res} - Interpretation"] = 'Susceptible'
-                elif len(tmp_results[res]) == 1:
-                    results[f"{res} - Interpretation"] = 'Intermediate'
+                # elif len(tmp_results[res]) == 1:
+                #     results[f"{res} - Interpretation"] = 'Intermediate'
                 else:
                     results[f"{res} - Interpretation"] = 'Resistant'
             elif res not in ["Aminoglycosides (RMT)","Colistin", "Other"]:
@@ -615,6 +618,7 @@ class MduCollate(Collate):
 
             
     def reporting_logic_general(self, row, species, neg_code = True):
+        
         # get all genes found
         all_genes = self.get_all_genes(row)
         isodict = row[1].to_dict()
@@ -623,19 +627,20 @@ class MduCollate(Collate):
         reportable = [
             "Carbapenemase",
             "Carbapenemase (MBL)",
-            "Carbapenemase (KPC variant)"
+            "ESBL (KPC variant)"
             "Carbapenemase (OXA-51 family)",
             "ESBL",
-            "ESBL (AmpC type)",
+            "AmpC", # will need to change to reflect new subclass AmpC
             "Aminoglycosides (Ribosomal methyltransferase)",
             "Colistin",
-            "Oxazolidinone & phenicol resistance", # Oxazolidinone or linezolid = reportable
+            "Chloramphenicol/Florfenicol/Linezolid", 
+            "Florfenicol/Oxazolidinone",
             "Vancomycin",
             "Methicillin"
         ]
         non_caveat_reportable = [
             "Carbapenemase",
-            "Carbapenemase (KPC variant)",
+            "ESBL (KPC variant)",
             "Aminoglycosides (Ribosomal methyltransferase)",
             "Colistin"
         ]
@@ -662,9 +667,10 @@ class MduCollate(Collate):
             if i != 'Isolate':
                 if isinstance(isodict[i], str):
                     genes = isodict[i].split(',')
-                    genes = [gene for gene in genes if '_' not in gene]
+                    genes = [gene for gene in genes if '_' not in gene] # this is to remove the point mutations for MMS118
                 if genes != []: # for each bin we do things to genes
                     if i in reportable: #don't report point mutations
+                        # print(i)
                         if i in non_caveat_reportable:
                             genes_reported.extend(genes)
                         elif i == "Carbapenemase (MBL)" and species != "Stenotrophomonas maltophilia":
@@ -675,9 +681,9 @@ class MduCollate(Collate):
                             genes_not_reported.extend([g for g in genes if g.startswith("blaL1")])
                         elif i == "Carbapenemase (OXA-51 family)" and species not in abacter_excluded:
                             genes_reported.extend(genes)
-                        elif i in ["ESBL","ESBL (AmpC type)"] and genus in ["Salmonella"]: 
+                        elif i in ["ESBL","AmpC"] and genus in ["Salmonella"]: 
                             genes_reported.extend(genes)
-                        elif i in ["ESBL","ESBL (AmpC type)"] and genus in ["Shigella"]: 
+                        elif i in ["ESBL","AmpC"] and genus in ["Shigella"]: 
                             genes_reported.extend([g for g in genes if "blaEC" not in g])
                             genes_not_reported.extend([g for g in genes if "blaEC" in g]) # don't report blaEC for shigella
                         elif i == "Vancomycin":
@@ -686,11 +692,12 @@ class MduCollate(Collate):
                         elif i == "Methicillin":
                             genes_reported.extend([g for g in genes if mec_match.match(g)])
                             genes_not_reported.extend([g for g in genes if not mec_match.match(g)])
-                        else:
-                            genes_not_reported.extend(genes)
-                    elif "Oxazolidinone" in i or "Linezolid" in i:
-                        if species in ["Staphylococcus aureus","Staphylococcus argenteus"] or genus == "Enterococcus":
-                            genes_reported.extend(genes)
+                        
+                        elif "Oxazolidinone" in i or "Linezolid" in i:
+                            if species in ["Staphylococcus aureus","Staphylococcus argenteus"] or genus == "Enterococcus":
+                                genes_reported.extend(genes)
+                            else:
+                                genes_not_reported.extend(genes)
                         else:
                             genes_not_reported.extend(genes)
 
@@ -742,6 +749,7 @@ class MduCollate(Collate):
                 result_df = tmpdf
             else:
                 result_df = result_df.append(tmpdf)
+        
         return result_df[cols]
 
     def _extract_plus_isolates(self,species):
@@ -755,7 +763,7 @@ class MduCollate(Collate):
     def mdu_reporting_general(self, match, neg_code = True):
 
         self.logger.info(f"Applying MDU business logic {'matches' if neg_code else 'partials'}.")
-        mduidreg = re.compile(r'(?P<id>[0-9]{4}-[0-9]{5,6})-?(?P<itemcode>.{1,2})?')
+        mduidreg = re.compile(r'(?P<id>[0-9]{4}-[0-9]{5,6})-?(?P<itemcode>.{1,})?')
         reporting_df = pandas.DataFrame()
         qc = self.mdu_qc_tab()
         match_df = pandas.read_csv(match, sep = '\t')
@@ -767,8 +775,13 @@ class MduCollate(Collate):
             qcdf = qc[qc['ISOLATE'].str.contains(isolate)]
             exp_species = qcdf["SPECIES_EXP"].values[0]
             obs_species = qcdf["SPECIES_OBS"].values[0]
-           
-            species = obs_species if obs_species == exp_species else exp_species
+            if obs_species == exp_species:
+                species = exp_species
+            elif obs_species != exp_species and 'Shigella' in exp_species:
+                species = exp_species
+            else:
+                species = obs_species
+            # species = obs_species if obs_species == exp_species else obs_species
             genes_reported, genes_not_reported = self.reporting_logic_general(
                 row=row, species=species, neg_code=neg_code
             )
@@ -791,8 +804,8 @@ class MduCollate(Collate):
             if reporting_df.empty:
                 reporting_df = tempdf
             else:
-                reporting_df = reporting_df.append(tempdf)
-        
+                reporting_df = pandas.concat([reporting_df,tempdf])
+            
         return reporting_df.reindex(labels = ['Item code','Resistance genes (alleles) detected','Resistance genes (alleles) det (non-rpt)','Species_obs', 'Species_exp', 'db_version'], axis = 'columns')
 
     
@@ -802,16 +815,16 @@ class MduCollate(Collate):
         passed_partials,
         
     ):
-        self.logger.info(f"Saving MMS118.")
-        writer = pandas.ExcelWriter(f"{self.runid}_MMS118.xlsx", engine="xlsxwriter")
-        passed_match.to_excel(writer, sheet_name="MMS118")
+        self.logger.info(f"Saving {self.sop_name}.")
+        writer = pandas.ExcelWriter(f"{self.runid}_{self.sop_name}.xlsx", engine="xlsxwriter")
+        passed_match.to_excel(writer, sheet_name=f"{self.sop_name}")
         passed_partials.to_excel(writer, sheet_name="Passed QC partial")
         writer.close()
 
     def save_spreadsheet_interpreted(self, results):
-        sheets = {"Salmonella enterica":"MMS184-01"}
+        sheets = {"Salmonella enterica":f"{self.sop_name}-01"}
         self.logger.info(f"Saving MMS184")
-        writer = pandas.ExcelWriter(f"{self.runid}_MMS184.xlsx", engine = "xlsxwriter")
+        writer = pandas.ExcelWriter(f"{self.runid}_{self.sop_name}.xlsx", engine = "xlsxwriter")
         for result in results:
             result[1].to_excel(writer, sheet_name = sheets[result[0]], index = False)
         writer.close()
